package cn.com.qmth.scancentral.controller.admin;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.qmth.boot.api.annotation.Aac;
import com.qmth.boot.api.constant.ApiConstant;

import cn.com.qmth.scancentral.bean.User;
import cn.com.qmth.scancentral.controller.BaseController;
import cn.com.qmth.scancentral.service.OmrTaskService;
import cn.com.qmth.scancentral.vo.task.TaskResultVo;
import cn.com.qmth.scancentral.vo.task.TaskSaveVo;
import cn.com.qmth.scancentral.vo.task.TaskStatusVo;
import cn.com.qmth.scancentral.vo.task.TaskVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@RestController
@Api(tags = "识别对照接口")
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/admin/check/omr/arbitrate")
@Aac(strict = false, auth = true)
public class ArbitrateController extends BaseController {

    protected static final Logger log = LoggerFactory.getLogger(ArbitrateController.class);

    @Autowired
    private OmrTaskService omrTaskService;

    @ApiOperation(value = "识别对照仲裁任务获取")
    @RequestMapping(value = "/get", method = RequestMethod.POST)
    public TaskVo get(@RequestParam Long examId) {
        User user = getAccessUser();
        return omrTaskService.getArbitrateTask(examId, user.getAccount());
    }

    @ApiOperation(value = "识别对照仲裁结果提交")
    @RequestMapping(value = "/save", method = RequestMethod.POST)
    public TaskSaveVo save(@RequestBody TaskResultVo result) {
        User user = getAccessUser();
        return omrTaskService.submitTask(result, user);
    }

    @ApiOperation(value = "识别对照仲裁进度状态")
    @RequestMapping(value = "/status", method = RequestMethod.POST)
    public TaskStatusVo status(@RequestParam Long examId) {
        User user = getAccessUser();
        return omrTaskService.getStatus(examId, true, user.getAccount());
    }

    @ApiOperation(value = "识别对照仲裁任务释放")
    @RequestMapping(value = "/release", method = RequestMethod.POST)
    public Object release(@RequestParam Long examId) {
        User user = getAccessUser();
        omrTaskService.releaseByUser(examId, user.getAccount());
        return success(true);
    }
    
    @ApiOperation(value = "识别对照仲裁任务历史")
    @RequestMapping(value = "/history", method = RequestMethod.POST)
    public TaskVo history(@RequestParam Long examId,@RequestParam(required = false) Long id,@RequestParam(required = false) Boolean next) {
        User user = getAccessUser();
        return omrTaskService.getArbitrateHistory(examId, id, user.getAccount(),next);
    }
}
